AzhonAppUpdate class

Constructors

AzhonAppUpdate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

getVersionCode Future<int>
获取应用的versionCode
no setter
getVersionName Future<String>
获取应用的versionName
no setter

Static Methods

cancel() Future<bool>
取消
cancelNotify() Future<bool>
删除通知栏消息
dispose() → void
install(String apkPath, {String? authorities}) Future<bool>
安装应用
listener(ValueChanged<ResultModel> callback) → void
监听
release() Future<bool>
释放DownloadManager
update(UpdateModel model) Future<bool>
更新